BytesLoader class abstract

An interface that can be implemented to support decoding vector graphic binary assets from different byte sources.

A bytes loader class should not be constructed directly in a build method, if this is done the corresponding VectorGraphic widget may repeatedly reload the bytes.

Implementations must overide toString for debug reporting.

See also:

  • AssetBytesLoader, for loading from the asset bundle.
  • NetworkBytesLoader, for loading network bytes.
Annotations

Constructors

BytesLoader()
Const constructor to allow subtypes to be const.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheKey(BuildContext? context) → Object
Create an object that can be used to uniquely identify this asset and loader combination.
loadBytes(BuildContext? context) → Future<ByteData>
Load the byte data for a vector graphic binary asset.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited